% Spin-correlated P3HT•+ and PCBM•- polaron pair
%===========================================================
% Singlet-born spin-correlated polaron pair generated by
% photoexcitation of a P3HT:PCBM blend for organic
% photovoltaics (single fixed relative orientation)
%
% see
%  - Kraffert and Behrends, Mol. Phys. 115, 2373–2386 (2017)
%    https://doi.org/10.1080/00268976.2016.1278479
%

clear; clc; clf;

% Spin system parameters
Sys.S = [1/2 1/2];
Sys.g = [2.0028 2.0018 2.0007;  % P3HT
         2.0001 2.0001 1.9989]; % PC61BM
Sys.gStrain = [0.0006 0.0006 0.0006;
               0.0001 0.0001 0.0012];

Sys.J = -3; % MHz
Sys.dip = -0.5; % MHz

Sys.lwpp = 0.2; % mT

% Specify singlet-born radical pair
Sys.initState = 'singlet';

% X-band
Exp(1).Range = [343 350]; % mT
Exp(1).mwFreq = 9.7; % GHz
Exp(1).Harmonic = 0;

% Q-band
Exp(2).Range = [1210 1218]; % mT
Exp(2).mwFreq = 34; % GHz
Exp(2).Harmonic = 0;

sgtitle('Singlet-born P3HT^{•+} PC_{61}BM^{•-} polaron pair','FontSize',9,'FontWeight','bold')
for i = 1:2
  
  [B,spc] = pepper(Sys,Exp(i));
  
  % Plot result
  subplot(2,1,i)
  plot(B,spc,'k')
  legend(['\nu_{mw} = ',num2str(Exp(i).mwFreq,'%1.2f'),'GHz'])
  xlabel('Magnetic Field (mT)')
  
end
